import 'dart:async';

import 'package:flutter/material.dart';

part 'streamed.dart';

/// The class representing a streamed value
class Streamable<T> {
  /// Classes containing this object need to implement [Forgettable]
  Streamable(T defaultValue) {
    _value = defaultValue;
    stream.listen((event) {
      _value = event;
    });
  }

  final _controller = StreamController<T>.broadcast();

  /// The stream of values to subscribe to
  Stream<T> get stream => _controller.stream;

  /// The latest value of the stream
  T get value => _value;

  set value(T val) {
    _value = val;
    _controller.add(_value);
  }

  late T _value;
}
